# =====================================
# generator=datazen
# version=2.1.0
# hash=1650ed0ffb4f69b694c413014dfb5db3
# =====================================

"""
Useful defaults and other package metadata.
"""

DESCRIPTION = "A collection of core Python utilities."
PKG_NAME = "vcorelib"
VERSION = "0.10.1"

DEFAULT_INDENT = 2
DEFAULT_ENCODING = "utf-8"
